@@ -3,7 +3,7 @@ package LBMA::Statistics::SilverFixing::Daily;
 use warnings;
 use strict;
 
-our $VERSION = '0.041';
+our $VERSION = '0.042';
 
 use WWW::Mechanize;
 use HTML::TableExtract;
@@ -94,9 +94,9 @@ determines url for daily silverstats
 
 sub dailystatsurl {
         my $self = shift;
-        my $url = 'http://www.lbma.org.uk/?area=stats&page=silver/';
+        my $url = 'http://www.lbma.org.uk/pages/?page_id=54&title=silver_fixings&show=';
         $url .= $self->year() ;
-        $url .= 'dailysilver';
+        $url .= '&type=daily';
 	return $url;
 }
 
@@ -179,7 +179,7 @@ automatically be notified of progress on your bug as I make changes.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009 Thomas Fahle
+Copyright 2009, 2010 Thomas Fahle
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
